@@ -5,6 +5,7 @@
 from labstep.generic.entityWithComments.model import EntityWithComments
 import labstep.generic.entity.repository as entityRepository
 from labstep.service.helpers import getTime
+from labstep.constants import UNSPECIFIED
 
 
 class ExperimentDataField(EntityWithComments):
@@ -24,7 +25,7 @@ class ExperimentDataField(EntityWithComments):
     __entityName__ = "metadata"
     __searchKey__ = 'label'
 
-    def edit(self, fieldName=None, value=None, extraParams={}):
+    def edit(self, fieldName=UNSPECIFIED, value=UNSPECIFIED, extraParams={}):
         """
         Edit the value of an existing data field.
 
