@@ -22,7 +22,7 @@ class Permission:
         -------
         None
         """
-        from labstep.entities.permission.repository import permissionRepository
+        import labstep.entities.permission.repository as permissionRepository
 
         permissionRepository.editPermission(
             self.entity, self.workspace["id"], permission
@@ -40,6 +40,7 @@ class Permission:
         -------
         None
         """
-        from labstep.entities.permission.repository import permissionRepository
+        import labstep.entities.permission.repository as permissionRepository
 
-        permissionRepository.revokePermission(self.entity, self.workspace["id"])
+        permissionRepository.revokePermission(
+            self.entity, self.workspace["id"])
