@@ -14,6 +14,7 @@ from labstep.generic.entityList.model import EntityList
 from labstep.entities.file.model import File
 import labstep.entities.file.repository as fileRepository
 from labstep.service.helpers import getTime
+from labstep.constants import UNSPECIFIED
 
 
 class Protocol(EntityPrimary):
@@ -33,7 +34,7 @@ class Protocol(EntityPrimary):
     __entityName__ = "protocol-collection"
     __searchKey__ = 'label'
 
-    def edit(self, name=None, body=None, extraParams={}):
+    def edit(self, name=UNSPECIFIED, body=UNSPECIFIED, extraParams={}):
         """
         Edit an existing Protocol.
 
@@ -207,11 +208,11 @@ class Protocol(EntityPrimary):
         self,
         fieldName,
         fieldType="default",
-        value=None,
-        date=None,
-        number=None,
-        unit=None,
-        filepath=None,
+        value=UNSPECIFIED,
+        date=UNSPECIFIED,
+        number=UNSPECIFIED,
+        unit=UNSPECIFIED,
+        filepath=UNSPECIFIED,
         extraParams={},
     ):
         """
@@ -262,7 +263,7 @@ class Protocol(EntityPrimary):
         )
 
     def addMaterial(
-        self, name=None, amount=None, units=None, resource_id=None, extraParams={}
+        self, name=UNSPECIFIED, amount=UNSPECIFIED, units=UNSPECIFIED, resource_id=UNSPECIFIED, extraParams={}
     ):
         """
         Add a new material to the Protocol.
@@ -323,7 +324,7 @@ class Protocol(EntityPrimary):
         materials = self.last_version["protocol_values"]
         return EntityList(materials, ProtocolMaterial, self.__user__)
 
-    def addTimer(self, name=None, hours=None, minutes=None, seconds=None):
+    def addTimer(self, name=UNSPECIFIED, hours=UNSPECIFIED, minutes=UNSPECIFIED, seconds=UNSPECIFIED):
         """
         Add a new timer to the Protocol.
 
@@ -385,7 +386,7 @@ class Protocol(EntityPrimary):
         timers = self.last_version["protocol_timers"]
         return EntityList(timers, ProtocolTimer, self.__user__)
 
-    def addTable(self, name=None, data=None):
+    def addTable(self, name=UNSPECIFIED, data=UNSPECIFIED):
         """
         Add a new table to the Protocol.
 
@@ -495,7 +496,7 @@ class Protocol(EntityPrimary):
 
         return collectionRepository.removeFromCollection(self, collection_id)
 
-    def addFile(self, filepath=None, rawData=None):
+    def addFile(self, filepath=UNSPECIFIED, rawData=UNSPECIFIED):
         """
         Add a file to a Protocol.
 
