@@ -4,6 +4,7 @@
 
 from labstep.entities.protocolMaterial.model import ProtocolMaterial
 import labstep.generic.entity.repository as entityRepository
+from labstep.constants import UNSPECIFIED
 
 
 def getProtocolMaterial(user, protocol_material_id):
@@ -20,7 +21,7 @@ def getProtocolMaterials(user, protocol_id, count=100, extraParams={}):
     return entityRepository.getEntities(user, ProtocolMaterial, count, params)
 
 
-def newProtocolMaterial(user, protocol_id, name, resource_id=None, amount=None, units=None, extraParams={}):
+def newProtocolMaterial(user, protocol_id, name, resource_id=UNSPECIFIED, amount=UNSPECIFIED, units=UNSPECIFIED, extraParams={}):
     params = {
         "protocol_id": protocol_id,
         "name": name,
@@ -30,13 +31,13 @@ def newProtocolMaterial(user, protocol_id, name, resource_id=None, amount=None,
         **extraParams,
     }
 
-    if params["value"] is not None:
+    if params["value"] is not UNSPECIFIED:
         params["value"] = str(params["value"])
 
     return entityRepository.newEntity(user, ProtocolMaterial, params)
 
 
-def editProtocolMaterial(protocol_material, name=None, amount=None, units=None, resource_id=None, extraParams={}):
+def editProtocolMaterial(protocol_material, name=UNSPECIFIED, amount=UNSPECIFIED, units=UNSPECIFIED, resource_id=UNSPECIFIED, extraParams={}):
     params = {
         "name": name,
         "value": amount,
