@@ -3,9 +3,9 @@
 # Author: Barney Walker <barney@labstep.com>
 
 import inspect
-import json
 import pprint
 from labstep.service.helpers import update
+from labstep.constants import UNSPECIFIED
 
 
 class Entity:
@@ -25,6 +25,9 @@ class Entity:
         pp = pprint.PrettyPrinter(indent=1)
         return pp.pformat(entity_attributes)
 
+    def __getitem__(self, key):
+        return getattr(self, key, None)
+
     def update(self):
         """
         Fetches the most up-to-date version of the entity from Labstep.
@@ -36,7 +39,7 @@ class Entity:
         self.__init__(data, self.__user__)
         return self
 
-    def export(self, rootPath, folderName=None):
+    def export(self, rootPath, folderName=UNSPECIFIED):
         """
         Export the entity to the directory specified. 
 
