@@ -8,11 +8,13 @@ from pathvalidate import sanitize_filepath
 from labstep.generic.entityList.model import EntityList
 from labstep.service.config import configService
 from labstep.service.helpers import (
+    filterUnspecified,
     url_join,
     getHeaders,
 )
 from labstep.service.request import requestService
 from labstep.config.export import entityNameInFolderName
+from labstep.constants import UNSPECIFIED
 
 
 def getLegacyEntity(user, entityClass, id):
@@ -40,7 +42,8 @@ def getEntity(user, entityClass, id, isDeleted="both", useGuid=False):
 
 
 def getEntities(user, entityClass, count, filterParams={}):
-    countParameter = min(count, 50) if count is not None else None
+    countParameter = min(
+        count, 50) if count is not UNSPECIFIED else UNSPECIFIED
     searchParams = {"search": 1, "cursor": -1, "count": countParameter}
 
     params = {**searchParams, **filterParams}
@@ -51,13 +54,19 @@ def getEntities(user, entityClass, count, filterParams={}):
     response = requestService.get(url, params=params, headers=headers)
     resp = json.loads(response.content)
     items = resp["items"]
-    expectedResults = min(
-        resp["total"], count) if count is not None else resp["total"]
-    while len(items) < expectedResults:
+
+    while resp["next_cursor"] != '-1':
+        if count is not UNSPECIFIED:
+            remainingItems = count - len(items)
+            params["count"] = min(remainingItems, 50)
+            if remainingItems <= 0:
+                break
+
         params["cursor"] = resp["next_cursor"]
         response = requestService.get(url, headers=headers, params=params)
         resp = json.loads(response.content)
         items.extend(resp["items"])
+
     return EntityList(items, entityClass, user)
 
 
@@ -65,8 +74,6 @@ def newEntity(user, entityClass, fields):
     headers = getHeaders(user=user)
     url = url_join(configService.getHost(), "/api/generic/",
                    entityClass.__entityName__)
-    fields = dict(
-        filter(lambda field: field[1] is not None, fields.items()))
 
     if "group_id" not in fields and getattr(
         entityClass, "__hasParentGroup__", False
@@ -102,27 +109,22 @@ def newEntities(user, entityClass, items):
 
 
 def editEntity(entity, fields):
-    # Filter the 'fields' dictionary by removing {'fields': None}
-    # to preserve the existing data in the 'fields', otherwise
-    # the 'fields' will be overwritten to 'None'.
     identifier = entity.guid if getattr(
         entity, "__hasGuid__", None) and hasattr(entity, 'guid') else entity.id
 
-    newFields = dict(
-        filter(lambda field: field[1] is not None, fields.items()))
     headers = getHeaders(entity.__user__)
     url = url_join(configService.getHost(), "/api/generic/",
                    entity.__entityName__, str(identifier))
-    response = requestService.put(url, json=newFields, headers=headers)
+    response = requestService.put(url, json=fields, headers=headers)
     entity.__init__(json.loads(response.content), entity.__user__)
     return entity
 
 
-def exportEntity(entity, rootPath, folderName=None):
+def exportEntity(entity, rootPath, folderName=UNSPECIFIED):
 
     from labstep.entities.file.model import File
 
-    if folderName is None:
+    if folderName is UNSPECIFIED:
         if entityNameInFolderName:
             folderName = f'{entity.id} - {entity.name}' if hasattr(
                 entity, 'name') else f'{entity.id}'
