@@ -1,11 +1,10 @@
 #!/usr/bin/env python3
 # -*- coding: utf-8 -*-
 # Author: Barney Walker <barney@labstep.com>
-
+import pandas
 from datetime import datetime
 from time import gmtime, strftime
-from labstep.constants.version import VERSION
-import pandas
+from labstep.constants import VERSION, UNSPECIFIED
 
 
 def url_join(*args):
@@ -62,6 +61,9 @@ def formatDate(date, time=True):
     if date is None:
         return None
 
+    if date is UNSPECIFIED:
+        return UNSPECIFIED
+
     format = '%Y-%m-%d %H:%M:%S' if time else '%Y-%m-%d'
 
     return datetime.strptime(date, '%Y-%m-%dT%H:%M:%S+00:00').strftime(format)
@@ -76,6 +78,9 @@ def handleDate(date):
     if date is None:
         return None
 
+    if date is UNSPECIFIED:
+        return UNSPECIFIED
+
     for fmt in ('%Y-%m-%d', '%Y-%m-%d %H:%M', '%Y-%m-%d %H:%M:%S'):
         try:
             return datetime.strptime(date, fmt).strftime('%Y-%m-%dT%H:%M:%S+00:00')
@@ -89,7 +94,12 @@ def handleString(string):
     """
     Casts to string or returns None
     """
-    return str(string) if string else None
+    if string is None:
+        return None
+    if string is UNSPECIFIED:
+        return UNSPECIFIED
+
+    return str(string)
 
 
 def handleKeyword(string):
@@ -101,6 +111,9 @@ def handleKeyword(string):
     """
     if string is None:
         return None
+    if string is UNSPECIFIED:
+        return UNSPECIFIED
+
     else:
         return string.lower().replace(" ", "_")
 
@@ -129,15 +142,36 @@ def getHeaders(user=None):
         }
 
 
+def boolToString(kv):
+    """ convert bool values to 'true'/'false' strings for json compat """
+    def enc(x): return x if not isinstance(
+        x, bool) else 'true' if x else 'false'
+
+    return None if kv is None else {k: enc(v) for k, v in kv.items()}
+
+
+def filterUnspecified(obj):
+    return None if obj is None else {k: v for (k, v) in obj.items() if v is not UNSPECIFIED}
+
+
 def getKeyValues(obj):
     return obj.items() if isinstance(obj, dict) else enumerate(obj)
 
 
+def getCellValue(cell):
+    if 'value' not in cell:
+        return None
+    if isinstance(cell['value'], str):
+        return str(cell['value']).strip()
+
+    return cell['value']
+
+
 def dataTableToDataFrame(dataTable):
 
     values = {
         str(rowKey): {
-            str(columnKey): str(cell['value']).strip() if isinstance(cell['value'], str) else cell['value']
+            str(columnKey): getCellValue(cell)
             for (columnKey, cell) in getKeyValues(row)
         } for (rowKey, row) in getKeyValues(dataTable)
     }
